/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
 */
package org.apache.qpid.qmf2.console;

import java.util.Map;

// QMF2 Imports
import org.apache.qpid.qmf2.common.QmfEvent;

/**
 * Descriptions below are taken from <a href=https://cwiki.apache.org/confluence/display/qpid/QMFv2+API+Proposal>QMF2 API Proposal</a> 
 * <pre>
 * EVENT_RECEIVED: When an Agent generates a QmfEvent an EVENT_RECEIVED WorkItem is pushed onto the work-queue.
 *                 The WorkItem's getParam() call returns a map which contains a reference to the Console Agent
 *                 instance that generated the Event and a reference to the QmfEvent itself. The Agent reference
 *                 is indexed from the map using the key string "agent, The QmfEvent reference is indexed from
 *                 the map using the key string "event". There is no handle associated with this WorkItem.
 * </pre>
 * @author Fraser Adams
 */

public final class EventReceivedWorkItem extends AgentAccessWorkItem
{
    /**
     * Construct a EventReceivedWorkItem. Convenience constructor not in API
     *
     * @param agent the Agent used to populate the WorkItem's param
     * @param event the QmfEvent used to populate the WorkItem's param
     */
    public EventReceivedWorkItem(final Agent agent, final QmfEvent event)
    {
        super(WorkItemType.EVENT_RECEIVED, null, newParams(agent, event));
    }

    /**
     * Return the QmfEvent stored in the params Map.
     * @return the QmfEvent stored in the params Map.
     */
    public QmfEvent getEvent()
    {
        Map<String, Object> p = this.<Map<String, Object>>getParams();
        return (QmfEvent)p.get("event");
    }
}

